]> git.mxchange.org Git - friendica.git/commitdiff
automated versioning
authorFriendika <info@friendika.com>
Thu, 10 Mar 2011 00:57:22 +0000 (16:57 -0800)
committerFriendika <info@friendika.com>
Thu, 10 Mar 2011 00:57:22 +0000 (16:57 -0800)
.gitignore
boot.php
update.php

index fea5fb91e02ededbbb2c0dbbaf54f954709b84ba..10a7187cf3bdb3ff2b468fcd2cdf62f34181d31f 100644 (file)
@@ -4,5 +4,6 @@ wip/*
 include/jquery-1.4.2.min.js
 *.log
 *.out
+*.version*
 push*
 home.html
index 37cd4259238a9fb77d234dd091c3fdfca3c09fb3..7dd188ee715129be2bc80f2db1981e4d831f29ad 100644 (file)
--- a/boot.php
+++ b/boot.php
@@ -2,9 +2,9 @@
 
 set_time_limit(0);
 
-define ( 'BUILD_ID',               1040   );
-define ( 'FRIENDIKA_VERSION',      '2.10.0912' );
+define ( 'FRIENDIKA_VERSION',      '2.1.913' );
 define ( 'DFRN_PROTOCOL_VERSION',  '2.1'  );
+define ( 'DB_UPDATE_VERSION',      1040   );
 
 define ( 'EOL',                    "<br />\r\n"     );
 define ( 'ATOM_TIME',              'Y-m-d\TH:i:s\Z' );
@@ -435,15 +435,15 @@ function check_config(&$a) {
 
        $build = get_config('system','build');
        if(! x($build))
-               $build = set_config('system','build',BUILD_ID);
+               $build = set_config('system','build',DB_UPDATE_VERSION);
 
        $url = get_config('system','url');
        if(! x($url))
                $url = set_config('system','url',$a->get_baseurl());
 
-       if($build != BUILD_ID) {
+       if($build != DB_UPDATE_VERSION) {
                $stored = intval($build);
-               $current = intval(BUILD_ID);
+               $current = intval(DB_UPDATE_VERSION);
                if(($stored < $current) && file_exists('update.php')) {
                        // We're reporting a different version than what is currently installed.
                        // Run any existing update scripts to bring the database up to current.
@@ -455,7 +455,7 @@ function check_config(&$a) {
                                        $func($a);
                                }
                        }
-                       set_config('system','build', BUILD_ID);
+                       set_config('system','build', DB_UPDATE_VERSION);
                }
        }
 
index 88d038f94b3dfcbe7a8bc84c8e16bda82cb3bd7d..fe8052b00ff9106bcc141bb6276e755f9601530a 100644 (file)
  * Each function in this file is named update_nnnn() where nnnn is an increasing number 
  * which began counting at 1000.
  * 
* At the top of the file "boot.php" is a define for BUILD_ID. Any time there is a change
  * to the database schema or one which requires an upgrade path from the existing application,
- * the BUILD_ID is incremented.
+ * the DB_UPDATE_VERSION is incremented.
  *
* The current BUILD_ID is stored in the config area of the database. If the application starts up
* and BUILD_ID is greater than the last stored build number, we will process every update function 
* in order from the currently stored value to the new BUILD_ID. This is expected to bring the system 
  * up to current without requiring re-installation or manual intervention.
  *
* Once the upgrade functions have completed, the current BUILD_ID is stored as the current value.
* The BUILD_ID will always be one greater than the last numbered script in this file. 
  *
  * If you change the database schema, the following are required:
  *    1. Update the file database.sql to match the new schema.
*    2. Update this file by adding a new function at the end with the number of the current BUILD_ID.
  *       This function should modify the current database schema and perform any other steps necessary
  *       to ensure that upgrade is silent and free from requiring interaction.
*    3. Increment the BUILD_ID in boot.php
  *    4. TEST the upgrade prior to checkin and filing a pull request.
  *
  */
@@ -455,7 +455,7 @@ function check_config(&$a) {
  * which began counting at 1000.
  * 
- * At the top of the file "boot.php" is a define for BUILD_ID. Any time there is a change
+ * At the top of the file "boot.php" is a define for DB_UPDATE_VERSION. Any time there is a change
  * to the database schema or one which requires an upgrade path from the existing application,
@@ -455,7 +455,7 @@ function check_config(&$a) {
  *
- * The current BUILD_ID is stored in the config area of the database. If the application starts up
- * and BUILD_ID is greater than the last stored build number, we will process every update function 
- * in order from the currently stored value to the new BUILD_ID. This is expected to bring the system 
+ * The current DB_UPDATE_VERSION is stored in the config area of the database. If the application starts up
+ * and DB_UPDATE_VERSION is greater than the last stored build number, we will process every update function 
+ * in order from the currently stored value to the new DB_UPDATE_VERSION. This is expected to bring the system 
  * up to current without requiring re-installation or manual intervention.
  *
@@ -455,7 +455,7 @@ function check_config(&$a) {
  * up to current without requiring re-installation or manual intervention.
  *
- * Once the upgrade functions have completed, the current BUILD_ID is stored as the current value.
- * The BUILD_ID will always be one greater than the last numbered script in this file. 
+ * Once the upgrade functions have completed, the current DB_UPDATE_VERSION is stored as the current value.
+ * The DB_UPDATE_VERSION will always be one greater than the last numbered script in this file. 
  *
  * If you change the database schema, the following are required:
@@ -455,7 +455,7 @@ function check_config(&$a) {
  * If you change the database schema, the following are required:
  *    1. Update the file database.sql to match the new schema.
- *    2. Update this file by adding a new function at the end with the number of the current BUILD_ID.
+ *    2. Update this file by adding a new function at the end with the number of the current DB_UPDATE_VERSION.
  *       This function should modify the current database schema and perform any other steps necessary
  *       to ensure that upgrade is silent and free from requiring interaction.
@@ -455,7 +455,7 @@ function check_config(&$a) {
  *       This function should modify the current database schema and perform any other steps necessary
  *       to ensure that upgrade is silent and free from requiring interaction.
- *    3. Increment the BUILD_ID in boot.php
+ *    3. Increment the DB_UPDATE_VERSION in boot.php
  *    4. TEST the upgrade prior to checkin and filing a pull request.
  *